use argh::FromArgs;
use libstax::deno::ScriptRunner;
use std::path::PathBuf;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "dry-run")]
/// Dry run (print stacks to stdout)
pub(crate) struct Arguments {
    /// script to run
    #[argh(positional)]
    script_path: String,

    /// path to Typescript interpreter (Deno)
    #[argh(option, default = "PathBuf::from(\"deno\")")]
    interpreter_path: PathBuf,
}

pub(crate) async fn dry_run(args: Arguments) {
    let runner = ScriptRunner::new(args.interpreter_path);

    runner
        .check_script(&args.script_path)
        .await
        .expect("Failed to check script");

    let stacks_output = runner
        .run_script(&args.script_path)
        .await
        .expect("Failed to run script");

    println!("{}", String::from_utf8_lossy(&stacks_output));
}
