use argh::FromArgs;
use libstax::deno::ScriptRunner;
use std::path::PathBuf;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "export")]
/// Export stacks
pub(crate) struct Arguments {
    /// path to output directory
    #[argh(option, short = 'o', default = "PathBuf::from(\"output\")")]
    output_dir: PathBuf,

    /// path to Typescript interpreter (Deno)
    #[argh(option, default = "PathBuf::from(\"deno\")")]
    interpreter_path: PathBuf,

    /// script to run
    #[argh(positional)]
    script_path: String,
}

pub(crate) async fn export(args: Arguments) {
    let runner = ScriptRunner::new(args.interpreter_path);

    runner
        .check_script(&args.script_path)
        .await
        .expect("Failed to check script");

    runner
        .run_and_export(&args.script_path, &args.output_dir)
        .await
        .expect("Failed to export stacks");
}
