use argh::FromArgs;
use std::path::PathBuf;

mod deploy;
mod dryrun;
mod export;
mod op;

#[derive(FromArgs, PartialEq, Debug)]
/// Command line app for staxman actions
struct ScriptArguments {
    /// project root
    #[argh(option, short = 'd')]
    project_root: Option<PathBuf>,

    #[argh(subcommand)]
    action: ActionCommands,
}

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand)]
enum ActionCommands {
    Export(export::Arguments),
    DryRun(dryrun::Arguments),
    Deploy(deploy::Arguments),
    Op(op::Arguments),
}

#[tokio::main]
async fn main() {
    let args: ScriptArguments = argh::from_env();

    // Set current directory to project root
    if let Some(project_root) = args.project_root {
        std::env::set_current_dir(&project_root).expect("Failed to set current directory");
    }

    match args.action {
        ActionCommands::DryRun(args) => dryrun::dry_run(args).await,
        ActionCommands::Export(args) => export::export(args).await,
        ActionCommands::Deploy(args) => deploy::deploy(args).await,
        ActionCommands::Op(args) => op::op(args).await,
    }
}
