use argh::FromArgs;
use libstax::compose::ComposeRunner;
use std::path::PathBuf;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "op")]
/// Execute operation on a stack
pub(crate) struct Arguments {
    /// project name
    #[argh(positional)]
    project: String,

    /// operation
    #[argh(positional)]
    op: String,

    /// path to docker binary
    #[argh(option, default = "PathBuf::from(\"docker\")")]
    docker_cli_path: PathBuf,
}

pub(crate) async fn op(args: Arguments) {
    ComposeRunner::new(args.docker_cli_path)
        .stack_op(
            &args.project,
            match args.op.as_str() {
                "start" => libstax::compose::ComposeOperation::Start,
                "stop" => libstax::compose::ComposeOperation::Stop,
                "restart" => libstax::compose::ComposeOperation::Restart,
                "down" => libstax::compose::ComposeOperation::Down,
                "rm" => libstax::compose::ComposeOperation::Remove,
                "pause" => libstax::compose::ComposeOperation::Pause,
                "kill" => libstax::compose::ComposeOperation::Kill,
                "create" => libstax::compose::ComposeOperation::Create,
                "unpause" => libstax::compose::ComposeOperation::Unpause,
                _ => {
                    eprintln!("Unknown operation: {}", args.op);
                    std::process::exit(1);
                }
            },
        )
        .await;
}
